@@ -659,160 +659,6 @@ create_cdc_for_empty_file (CDCFileDescriptor *cdc)
     memset (cdc, 0, sizeof(CDCFileDescriptor));
 }
 
-#if defined SEAFILE_SERVER && defined FULL_FEATURE
-
-#define FIXED_BLOCK_SIZE (1<<20)
-
-typedef struct ChunkingData {
-    const char *repo_id;
-    int version;
-    const char *file_path;
-    SeafileCrypt *crypt;
-    guint8 *blk_sha1s;
-    GAsyncQueue *finished_tasks;
-} ChunkingData;
-
-static void
-chunking_worker (gpointer vdata, gpointer user_data)
-{
-    ChunkingData *data = user_data;
-    CDCDescriptor *chunk = vdata;
-    int fd = -1;
-    ssize_t n;
-    int idx;
-
-    chunk->block_buf = g_new0 (char, chunk->len);
-    if (!chunk->block_buf) {
-        seaf_warning ("Failed to allow chunk buffer\n");
-        goto out;
-    }
-
-    fd = seaf_util_open (data->file_path, O_RDONLY | O_BINARY);
-    if (fd < 0) {
-        seaf_warning ("Failed to open %s: %s\n", data->file_path, strerror(errno));
-        chunk->result = -1;
-        goto out;
-    }
-
-    if (seaf_util_lseek (fd, chunk->offset, SEEK_SET) == (gint64)-1) {
-        seaf_warning ("Failed to lseek %s: %s\n", data->file_path, strerror(errno));
-        chunk->result = -1;
-        goto out;
-    }
-
-    n = readn (fd, chunk->block_buf, chunk->len);
-    if (n < 0) {
-        seaf_warning ("Failed to read chunk from %s: %s\n",
-                      data->file_path, strerror(errno));
-        chunk->result = -1;
-        goto out;
-    }
-
-    chunk->result = seafile_write_chunk (data->repo_id, data->version,
-                                         chunk, data->crypt,
-                                         chunk->checksum, 1);
-    if (chunk->result < 0)
-        goto out;
-
-    idx = chunk->offset / FIXED_BLOCK_SIZE;
-    memcpy (data->blk_sha1s + idx * CHECKSUM_LENGTH, chunk->checksum, CHECKSUM_LENGTH);
-
-out:
-    g_free (chunk->block_buf);
-    close (fd);
-    g_async_queue_push (data->finished_tasks, chunk);
-}
-
-static int
-split_file_to_block (const char *repo_id,
-                     int version,
-                     const char *file_path,
-                     gint64 file_size,
-                     SeafileCrypt *crypt,
-                     CDCFileDescriptor *cdc,
-                     gboolean write_data)
-{
-    int n_blocks;
-    uint8_t *block_sha1s = NULL;
-    GThreadPool *tpool = NULL;
-    GAsyncQueue *finished_tasks = NULL;
-    GList *pending_tasks = NULL;
-    int n_pending = 0;
-    CDCDescriptor *chunk;
-    int ret = 0;
-
-    n_blocks = (file_size + BLOCK_SZ - 1) / BLOCK_SZ;
-    block_sha1s = g_new0 (uint8_t, n_blocks * CHECKSUM_LENGTH);
-    if (!block_sha1s) {
-        seaf_warning ("Failed to allocate block_sha1s.\n");
-        ret = -1;
-        goto out;
-    }
-
-    finished_tasks = g_async_queue_new ();
-
-    ChunkingData data;
-    memset (&data, 0, sizeof(data));
-    data.repo_id = repo_id;
-    data.version = version;
-    data.file_path = file_path;
-    data.crypt = crypt;
-    data.blk_sha1s = block_sha1s;
-    data.finished_tasks = finished_tasks;
-
-    tpool = g_thread_pool_new (chunking_worker, &data,
-                               seaf->http_server->max_indexing_threads, FALSE, NULL);
-    if (!tpool) {
-        seaf_warning ("Failed to allocate thread pool\n");
-        ret = -1;
-        goto out;
-    }
-
-    guint64 offset = 0;
-    guint64 len;
-    guint64 left = (guint64)file_size;
-    while (left > 0) {
-        len = ((left >= FIXED_BLOCK_SIZE) ? FIXED_BLOCK_SIZE : left);
-
-        chunk = g_new0 (CDCDescriptor, 1);
-        chunk->offset = offset;
-        chunk->len = (guint32)len;
-
-        g_thread_pool_push (tpool, chunk, NULL);
-        pending_tasks = g_list_prepend (pending_tasks, chunk);
-        n_pending++;
-
-        left -= len;
-        offset += len;
-    }
-
-    while ((chunk = g_async_queue_pop (finished_tasks)) != NULL) {
-        if (chunk->result < 0) {
-            ret = -1;
-            goto out;
-        }
-
-        if ((--n_pending) <= 0)
-            break;
-    }
-
-    cdc->block_nr = n_blocks;
-    cdc->blk_sha1s = block_sha1s;
-
-out:
-    if (tpool)
-        g_thread_pool_free (tpool, TRUE, TRUE);
-    if (finished_tasks)
-        g_async_queue_unref (finished_tasks);
-    g_list_free_full (pending_tasks, g_free);
-    if (ret < 0)
-        g_free (block_sha1s);
-
-    return ret;
-}
-
-#endif  /* SEAFILE_SERVER */
-
 int
 seaf_fs_manager_index_blocks (SeafFSManager *mgr,
                               const char *repo_id,
@@ -841,31 +687,9 @@ seaf_fs_manager_index_blocks (SeafFSManager *mgr,
     } else {
         memset (&cdc, 0, sizeof(cdc));
 
-#if defined SEAFILE_SERVER && defined FULL_FEATURE
-        if (use_cdc || version == 0) {
-            cdc.block_sz = calculate_chunk_size (sb.st_size);
-            cdc.block_min_sz = cdc.block_sz >> 2;
-            cdc.block_max_sz = cdc.block_sz << 2;
-            cdc.write_block = seafile_write_chunk;
-            memcpy (cdc.repo_id, repo_id, 36);
-            cdc.version = version;
-            if (filename_chunk_cdc (file_path, &cdc, crypt, write_data) < 0) {
-                seaf_warning ("Failed to chunk file with CDC.\n");
-                return -1;
-            }
-        } else {
-            memcpy (cdc.repo_id, repo_id, 36);
-            cdc.version = version;
-            cdc.file_size = sb.st_size;
-            if (split_file_to_block (repo_id, version, file_path, sb.st_size,
-                                     crypt, &cdc, write_data) < 0) {
-                return -1;
-            }
-        }
-#else
-        cdc.block_sz = calculate_chunk_size (sb.st_size);
-        cdc.block_min_sz = cdc.block_sz >> 2;
-        cdc.block_max_sz = cdc.block_sz << 2;
+        cdc.block_sz = CDC_AVERAGE_BLOCK_SIZE;
+        cdc.block_min_sz = CDC_MIN_BLOCK_SIZE;
+        cdc.block_max_sz = CDC_MAX_BLOCK_SIZE;
         cdc.write_block = seafile_write_chunk;
         memcpy (cdc.repo_id, repo_id, 36);
         cdc.version = version;
@@ -873,7 +697,6 @@ seaf_fs_manager_index_blocks (SeafFSManager *mgr,
             seaf_warning ("Failed to chunk file with CDC.\n");
             return -1;
         }
-#endif
 
         if (write_data && write_seafile (mgr, repo_id, version, &cdc, sha1) < 0) {
             g_free (cdc.blk_sha1s);
