@@ -463,6 +463,17 @@ void mark_all_ce_unused(struct index_state *index)
         index->cache[i]->ce_flags &= ~(CE_UNPACKED | CE_ADDED | CE_NEW_SKIP_WORKTREE);
 }
 
+static gboolean
+is_eml_file (const char *path)
+{
+    int len = strlen(path);
+    const char *ext;
+
+    if (len < 5)
+        return FALSE;
+    ext = &path[len-4];
+    return (strcasecmp (ext, ".eml") == 0);
+}
 
 static int ce_match_stat_basic(struct cache_entry *ce, SeafStat *st)
 {
@@ -497,7 +508,7 @@ static int ce_match_stat_basic(struct cache_entry *ce, SeafStat *st)
         seaf_warning("internal error: ce_mode is %o\n", ce->ce_mode);
         return -1;
     }
-    if (ce->ce_mtime.sec != st->st_mtime)
+    if (!is_eml_file (ce->name) && ce->ce_mtime.sec != st->st_mtime)
         changed |= MTIME_CHANGED;
     /* if (ce->ce_ctime.sec != st->st_ctime) */
     /*     changed |= CTIME_CHANGED; */
