@@ -286,6 +286,12 @@ http_tx_manager_unlock_file (HttpTxManager *manager,
                              const char *repo_id,
                              const char *path);
 
+GHashTable *
+http_tx_manager_get_head_commit_ids (HttpTxManager *manager,
+                                     const char *host,
+                                     gboolean use_fileserver_port,
+                                     GList *repo_id_list);
+
 int
 http_tx_task_download_file_blocks (HttpTxTask *task, const char *file_id);
 
