@@ -15,6 +15,7 @@
 
 #include <glib.h>
 #include <glib-object.h>
+#include <curl/curl.h>
 
 #ifdef HAVE_BREAKPAD_SUPPORT
 #include <c_bpwrapper.h>
@@ -503,6 +504,8 @@ main (int argc, char **argv)
 
     cdc_init ();
 
+    curl_global_init (CURL_GLOBAL_ALL);
+
 #if !GLIB_CHECK_VERSION(2, 35, 0)
     g_type_init();
 #endif
